@@ -1,12 +1,12 @@
-"""Submodule providing wrapper for PyKeen's TransR model."""
+"""Submodule providing wrapper for PyKEEN's TransR model."""
 from typing import Union, Type, Dict, Any
 from pykeen.training import TrainingLoop
 from pykeen.models import TransR
-from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKeen
+from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKEEN
 from pykeen.triples import CoreTriplesFactory
 
 
-class TransRPyKeen(EntityRelationEmbeddingModelPyKeen):
+class TransRPyKEEN(EntityRelationEmbeddingModelPyKEEN):
 
     def __init__(
         self,
@@ -21,12 +21,12 @@ class TransRPyKeen(EntityRelationEmbeddingModelPyKeen):
         random_state: int = 42,
         enable_cache: bool = False
     ):
-        """Create new PyKeen TransR model.
+        """Create new PyKEEN TransR model.
         
         Details
         -------------------------
         This is a wrapper of the TransR implementation from the
-        PyKeen library. Please refer to the PyKeen library documentation
+        PyKEEN library. Please refer to the PyKEEN library documentation
         for details and posssible errors regarding this model.
 
         Parameters
@@ -74,7 +74,7 @@ class TransRPyKeen(EntityRelationEmbeddingModelPyKeen):
     def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
-            **EntityRelationEmbeddingModelPyKeen.smoke_test_parameters(),
+            **EntityRelationEmbeddingModelPyKEEN.smoke_test_parameters(),
             scoring_fct_norm=1,
             relation_dim=5
         )
